@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.16'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 use 5.006;
@@ -93,9 +93,10 @@ sub script_compiles {
   my $args   = _script(shift);
   my $unix   = shift @$args;
   my $path   = path( $unix );
+  my $pargs  = _perl_args($path);
   my @libs   = map { "-I$_" } grep {!ref($_)} @INC;
   my $dir    = _preload_module();
-  my $cmd    = [ perl, "-I$dir", '-M__TEST_SCRIPT__', '-c', $path, @$args ];
+  my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', '-c', $path, @$args ];
   my $stdin  = '';
   my $stdout = '';
   my $stderr = '';
@@ -128,7 +129,7 @@ sub _preload_module
   # this is hopefully a pm file that nobody would use
   my $filename = File::Spec->catfile($dir, '__TEST_SCRIPT__.pm');
   my $fh;
-  open($fh, ">$filename") 
+  open($fh, '>', $filename) 
     || die "unable to open $filename: $!";
   print($fh 'unshift @INC, ',
     join ',', 
@@ -150,8 +151,9 @@ sub script_runs {
   my $opt    = _options(\@_);
   my $unix   = shift @$args;
   my $path   = path( $unix );
+  my $pargs  = _perl_args($path);
   my $dir    = _preload_module();
-  my $cmd    = [ perl, "-I$dir", '-M__TEST_SCRIPT__', $path, @$args ];
+  my $cmd    = [ perl, @$pargs, "-I$dir", '-M__TEST_SCRIPT__', $path, @$args ];
      $stdout = '';
      $stderr = '';
   my $rv     = eval { run3( $cmd, $opt->{stdin}, $opt->{stdout}, $opt->{stderr} ) };
@@ -276,6 +278,20 @@ sub _script {
   Carp::croak("Invalid command parameter");
 }
 
+# Determine any extra arguments that need to be passed into Perl.
+# ATM this is just -T.
+sub _perl_args {
+  my($script) = @_;
+  my $fh;
+  my $first_line = '';
+  if(open($fh, '<', $script))
+  {
+    $first_line = <$fh>;
+    close $fh;
+  }
+  (grep /^-.*T/, split /\s+/, $first_line) ? ['-T'] : [];
+}
+
 # Inline some basic Params::Util functions
 
 sub _options {
@@ -318,7 +334,7 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
